@@ -9,18 +9,16 @@ Scientific colormaps for making accessible, informative and *cmashing* plots.
 
 
 # %% IMPORTS AND DECLARATIONS
-# Future imports
-from __future__ import absolute_import, division, print_function
-
 # CMasher imports
 from .__version__ import __version__
 from . import utils
 from .utils import *
 from . import cm
 from .cm import *
+from . import app_usage
 
 # All declaration
-__all__ = ['cm', 'utils']
+__all__ = ['app_usage', 'cm', 'utils']
 __all__.extend(cm.__all__)
 __all__.extend(utils.__all__)
 
