@@ -14,6 +14,7 @@ from collections import OrderedDict as odict
 from glob import glob
 from os import path
 from textwrap import dedent
+import warnings
 
 # Package imports
 from colorspacious import cspace_converter
@@ -31,8 +32,9 @@ from cmasher import cm as cmrcm
 
 # All declaration
 __all__ = ['create_cmap_mod', 'create_cmap_overview', 'get_bibtex',
-           'get_cmap_type', 'get_sub_cmap', 'import_cmaps', 'register_cmap',
-           'set_cmap_legend_entry', 'take_cmap_colors']
+           'get_cmap_list', 'get_cmap_type', 'get_sub_cmap', 'import_cmaps',
+           'register_cmap', 'set_cmap_legend_entry', 'take_cmap_colors',
+           'view_cmap']
 
 
 # %% HELPER CLASSES
@@ -73,17 +75,19 @@ def _get_cmap_lightness_rank(cmap):
 
     Returns
     -------
+    L_slope : int
+        The slope type of lightness profile of `cmap`.
     L_type : int
-        The type of lightness profile of `cmap`.
+        The range type of lightness profile of `cmap`.
         This is only used for sequential colormaps.
     L_start : float
         The starting lightness value of `cmap`.
-        For diverging colormaps, this is the central lightness value.
+        For diverging/cyclic colormaps, this is the central lightness value.
     L_rng : float
-        The lightness range (L_max-L_min) of `cmap`.
+        The lightness range of `cmap`.
     L_rmse : float
         The RMSE of the lightness profile of `cmap`.
-        For diverging colormaps, this is the max RMSE of either half.
+        For diverging/cyclic colormaps, this is the max RMSE of either half.
     name : str
         The name of `cmap`.
         For qualitative and miscellaneous colormaps, this is the only value
@@ -93,55 +97,126 @@ def _get_cmap_lightness_rank(cmap):
 
     # Obtain the colormap
     cmap = mplcm.get_cmap(cmap)
+    cm_type = get_cmap_type(cmap)
 
-    # Get RGB values for colormap
-    rgb = cmap(np.arange(cmap.N))[:, :3]
+    # Determine lightness profile stats for sequential/diverging/cyclic
+    if cm_type in ('sequential', 'diverging', 'cyclic'):
+        # Get RGB values for colormap
+        rgb = cmap(np.arange(cmap.N))[:, :3]
 
-    # Get lightness values of colormap
-    lab = cspace_converter("sRGB1", "CAM02-UCS")(rgb)
-    L = lab[:, 0]
+        # Get lightness values of colormap
+        lab = cspace_converter("sRGB1", "CAM02-UCS")(rgb)
+        L = lab[:, 0]
 
-    # Determine the deltas of the lightness profile
-    deltas = np.diff(L)
-    derivs = (cmap.N-1)*deltas
+        # If cyclic colormap, add first L at the end
+        if(cm_type == 'cyclic'):
+            L = np.r_[L, [L[0]]]
 
-    # Set lightness profile type to 0
-    L_type = 0
+        # Determine number of values that will be in deltas
+        N_deltas = len(L)-1
 
-    # Determine the RMSE of the lightness profile of a sequential colormap
-    if(get_cmap_type(cmap) == 'sequential'):
-        # Take RMSE of entire lightness profile
-        L_rmse = np.around(np.std(derivs), 1)
+        # Determine the deltas of the lightness profile
+        deltas = np.diff(L)
+        derivs = N_deltas*deltas
 
-        # Calculate starting lightness value
-        L_start = np.around(L[0], 1)
+        # Set lightness profile type to 0
+        L_type = 0
 
-        # Determine type of lightness profile
-        L_type += ~(np.sum(rgb[0]) == 0)*2
-        L_type += ((np.sum(rgb[0]) == 0) == (np.sum(rgb[-1]) == 3))
+        # Determine the RMSE of the lightness profile of a sequential colormap
+        if(cm_type == 'sequential'):
+            # Take RMSE of entire lightness profile
+            L_rmse = np.around(np.std(derivs), 0)
 
-    # Diverging/cyclic colormaps
-    elif get_cmap_type(cmap) in ('diverging', 'cyclic'):
-        # Calculate RMSE of both halves
-        central_i = [int(np.floor(cmap.N/2)), int(np.ceil(cmap.N/2))]
-        L_rmse = np.max([np.around(np.std(derivs[:central_i[0]]), 1),
-                         np.around(np.std(derivs[central_i[1]:]), 1)])
+            # Calculate starting lightness value
+            L_start = np.around(L[0], 0)
 
-        # Calculate central lightness value
-        L_start = np.around(np.average(L[central_i]), 1)
+            # Determine type of lightness profile
+            L_type += (not np.allclose(rgb[0], [0, 0, 0]))*2
+            L_type += (np.allclose(rgb[0], [0, 0, 0]) ==
+                       np.allclose(rgb[-1], [1, 1, 1]))
 
-    # Determine lightness range for sequential/diverging/cyclic colormaps
-    if get_cmap_type(cmap) in ('sequential', 'diverging', 'cyclic'):
-        L_min = np.around(np.min(L), 1)
-        L_max = np.around(np.max(L), 1)
-        L_rng = np.around(np.abs(L_max-L_min), 1)
+        # Diverging/cyclic colormaps
+        else:
+            # Determine the center of the colormap
+            central_i = [int(np.ceil(N_deltas/2)), int(np.floor(N_deltas/2))]
+
+            # Calculate RMSE of both halves
+            L_rmse = np.max([np.around(np.std(derivs[:central_i[0]]), 0),
+                             np.around(np.std(derivs[central_i[1]:]), 0)])
+
+            # Calculate central lightness value
+            L_start = np.around(np.average(L[central_i]), 0)
+
+        # Determine lightness range
+        L_rng = np.around(np.max(L)-np.min(L), 0)
+
+        # Determine if cmap goes from dark to light or the opposite
+        L_slope = (L_start > L[-1])*2-1
 
     # For qualitative/misc colormaps, set all lightness values to zero
     else:
-        L_type = L_start = L_rng = L_rmse = 0
+        L_slope = L_type = L_start = L_rng = L_rmse = 0
 
     # Return lightness contributions to the rank
-    return(L_type, L_start, L_rng, L_rmse, cmap.name)
+    return(L_slope, L_type, L_start, L_rng, L_rmse, cmap.name)
+
+
+# Define function for obtaining the sorting order for perceptual ranking
+def _get_cmap_perceptual_rank(cmap):
+    """
+    In addition to returning the lightness rank as given by
+    :func:`~_get_cmap_lightness_rank`, also returns the length of the
+    perceptual profile, also known as the perceptual range, of the provided
+    `cmap`.
+
+    Parameters
+    ----------
+    cmap : str or :obj:`~matplotlib.colors.Colormap` object
+        The registered name of the colormap in :mod:`matplotlib.cm` or its
+        corresponding :obj:`~matplotlib.colors.Colormap` object.
+
+    Returns
+    -------
+    *L_rank : objects
+        The values returned by :func:`~_get_cmap_lightness_rank`, except for
+        the name of the colormap.
+    P_rng : float
+        The perceptual range of `cmap`.
+    name : str
+        The name of `cmap`.
+        For qualitative and miscellaneous colormaps, this is the only value
+        that is used.
+
+    """
+
+    # Obtain the colormap
+    cmap = mplcm.get_cmap(cmap)
+    cm_type = get_cmap_type(cmap)
+
+    # Determine perceptual range for sequential/diverging/cyclic
+    if cm_type in ('sequential', 'diverging', 'cyclic'):
+        # Get RGB values for colormap
+        rgb = cmap(np.arange(cmap.N))[:, :3]
+
+        # Get lab values of colormap
+        lab = cspace_converter("sRGB1", "CAM02-UCS")(rgb)
+
+        # If cyclic colormap, add first lab at the end
+        if(cm_type == 'cyclic'):
+            lab = np.r_[lab, [lab[0]]]
+
+        # Determine the deltas of the lightness profile
+        deltas = np.sqrt(np.sum(np.diff(lab, axis=0)**2, axis=-1))
+
+        # Determine perceptual range
+        P_rng = np.around(np.sum(deltas), 0)
+
+    # For qualitative/misc colormaps, set all values to zero
+    else:
+        P_rng = 0
+
+    # Return perceptual contributions to the rank
+    return(*_get_cmap_lightness_rank(cmap)[:-1], P_rng, cmap.name)
 
 
 # %% FUNCTIONS
@@ -198,6 +273,7 @@ def create_cmap_mod(cmap, *, save_dir='.'):
 
     # Obtain the CMasher colormap associated with the provided cmap
     cmap = cmrcm.cmap_d.get(name, None)
+    cm_type = get_cmap_type(cmap)
 
     # If cmap is None, raise error
     if cmap is None:
@@ -237,13 +313,33 @@ def create_cmap_mod(cmap, *, save_dir='.'):
         cm_data = {1}
 
         # Create ListedColormap object for this colormap
-        cmap = ListedColormap(cm_data, name='cmr.{2}', N=len(cm_data))
+        cmap = ListedColormap(cm_data, name='cmr.{2}', N={3})
         cmap_r = cmap.reversed()
 
         # Register (reversed) cmap in MPL
         register_cmap(cmap=cmap)
         register_cmap(cmap=cmap_r)
-        """).format(get_cmap_type(cmap), array_str, name)
+        """)
+
+    # If this colormap is cyclic, add code to register shifted version as well
+    if(cm_type == 'cyclic'):
+        cm_py_file += dedent("""
+            # Shift the entire colormap by half of its length
+            cm_data_s = list(cm_data[{4}:])
+            cm_data_s.extend(cm_data[:{4}])
+
+            # Create ListedColormap object for this shifted version
+            cmap_s = ListedColormap(cm_data_s, name='cmr.{2}_s', N={3})
+            cmap_s_r = cmap_s.reversed()
+
+            # Register shifted versions in MPL as well
+            register_cmap(cmap=cmap_s)
+            register_cmap(cmap=cmap_s_r)
+            """)
+
+    # Format py-file string
+    cm_py_file = cm_py_file.format(cm_type, array_str, name, len(rgb),
+                                   len(rgb)//2)
 
     # Obtain the path to the module
     cmap_path = path.join(save_dir, "{0}.py".format(name))
@@ -259,7 +355,7 @@ def create_cmap_mod(cmap, *, save_dir='.'):
 # This function creates an overview plot of all colormaps specified
 def create_cmap_overview(cmaps=None, *, savefig=None, use_types=True,
                          sort='alphabetical', show_grayscale=True,
-                         plot_profile=False, dark_mode=False,
+                         show_info=False, plot_profile=False, dark_mode=False,
                          title="Colormap Overview", wscale=1, hscale=1):
     """
     Creates an overview plot containing all colormaps defined in the provided
@@ -279,14 +375,18 @@ def create_cmap_overview(cmaps=None, *, savefig=None, use_types=True,
         Whether all colormaps in `cmaps` should be categorized into their
         colormap types (sequential; diverging; cyclic; qualitative; misc).
         If `cmaps` is a dict, this value is ignored.
-    sort : {'alphabetical'/'name'; 'lightness'}, function or None. Default: \
-        'alphabetical'
+    sort : {'alphabetical'/'name'; 'lightness'; 'perceptual'}, function or \
+        None. Default: 'alphabetical'
         String or function indicating how the colormaps should be sorted in the
         overview.
         If 'alphabetical', the colormaps are sorted alphabetically on their
         name.
         If 'lightness', the colormaps are sorted based on their lightness
-        profile.
+        profile, which is given by :func:`~_get_cmap_lightness_rank`.
+        If 'perceptual', the colormaps sorted based on their perceptual range
+        in  addition to their lightness profile, which is given by
+        :func:`~_get_cmap_perceptual_rank`. Note that this is only meaningful
+        if all `cmaps` are perceptually uniform sequential.
         If function, a function definition that takes a
         :obj:`~matplotlib.colors.Colormap` object and returns the sorted
         position of that colormap.
@@ -294,11 +394,17 @@ def create_cmap_overview(cmaps=None, *, savefig=None, use_types=True,
     show_grayscale : bool. Default: True
         Whether to show the grayscale versions of the given `cmaps` in the
         overview.
+    show_info : bool. Default: False
+        Whether the statistics information of all sequential, diverging and
+        cyclic colormaps should be shown under their names. This is a series of
+        numbers representing, in order, the starting (sequential) or central
+        (diverging/cyclic) lightness value; the final/outer lightness value;
+        and the perceptual range of the colormap.
     plot_profile : bool or float. Default: False
-        Whether the lightness profiles of all colormaps should be plotted. If
-        not *False*, the lightness profile of a colormap is plotted on top of
-        its gray-scale version and `plot_profile` is used for setting the alpha
-        (opacity) value.
+        Whether the lightness profiles of all non-qualitative colormaps should
+        be plotted. If not *False*, the lightness profile of a colormap is
+        plotted on top of its gray-scale version and `plot_profile` is used for
+        setting the alpha (opacity) value.
         If `plot_profile` is *True*, it will be set to `0.25`.
         If `show_grayscale` is *False*, this value is ignored.
     dark_mode : bool. Default: False
@@ -321,6 +427,10 @@ def create_cmap_overview(cmaps=None, *, savefig=None, use_types=True,
     Any provided reversed colormaps (colormaps that end their name with '_r')
     are ignored if their normal versions were provided as well.
 
+    When `sort` is 'lightness' or 'perceptual', qualitative and miscellaneous
+    colormaps are solely sorted on their names, as the lightness/perceptual
+    profile of these colormaps is meaningless.
+
     If `plot_profile` is not set to *False*, the lightness profiles are plotted
     on top of the gray-scale colormap versions, where the y-axis ranges from 0%
     lightness to 100% lightness.
@@ -328,37 +438,6 @@ def create_cmap_overview(cmaps=None, *, savefig=None, use_types=True,
 
     """
 
-    # Check value of show_grayscale
-    if show_grayscale:
-        # If True, the overview will have two columns
-        ncols = 2
-    else:
-        # If False, the overview will have one column and no profile plotted
-        ncols = 1
-        wscale *= 0.5
-        plot_profile = False
-
-    # Determine positions
-    wscale = 0.2+0.8*wscale
-    left_pos = 0.2/wscale
-    spacing = 0.01/wscale
-
-    # If plot_profile is True, set it to its default value
-    if plot_profile is True:
-        plot_profile = 0.25
-
-    # Check if dark mode is requested
-    if dark_mode:
-        # If so, use dark grey for the background and light grey for the text
-        edge_color = '#24292E'
-        face_color = '#24292E'
-        text_color = '#9DA5B4'
-    else:
-        # If not, use white for the background and black for the text
-        edge_color = '#FFFFFF'
-        face_color = '#FFFFFF'
-        text_color = '#000000'
-
     # If cmaps is None, use cmap_d.values
     if cmaps is None:
         cmaps = cmrcm.cmap_d.values()
@@ -374,6 +453,11 @@ def create_cmap_overview(cmaps=None, *, savefig=None, use_types=True,
                 return(x.name)
         elif(sort == 'lightness'):
             sort = _get_cmap_lightness_rank
+        elif(sort == 'perceptual'):
+            sort = _get_cmap_perceptual_rank
+        else:
+            raise ValueError("Input argument 'sort' has invalid string value "
+                             "%r!" % (sort))
 
     # Create empty list of cmaps
     cmaps_list = []
@@ -470,6 +554,37 @@ def create_cmap_overview(cmaps=None, *, savefig=None, use_types=True,
     # Obtain the colorspace converter for showing cmaps in grey-scale
     cspace_convert = cspace_converter("sRGB1", "CAM02-UCS")
 
+    # Check value of show_grayscale
+    if show_grayscale:
+        # If True, the overview will have two columns
+        ncols = 2
+    else:
+        # If False, the overview will have one column
+        ncols = 1
+        wscale *= 0.5
+
+    # Determine text/element positions
+    wscale = 0.2+0.8*wscale
+    left_pos = 0.2/wscale
+    spacing = 0.01/wscale
+    title_pos = left_pos+(1-spacing-left_pos)/2
+
+    # If plot_profile is True, set it to its default value
+    if plot_profile is True:
+        plot_profile = 0.25
+
+    # Check if dark mode is requested
+    if dark_mode:
+        # If so, use dark grey for the background and light grey for the text
+        edge_color = '#24292E'
+        face_color = '#24292E'
+        text_color = '#9DA5B4'
+    else:
+        # If not, use white for the background and black for the text
+        edge_color = '#FFFFFF'
+        face_color = '#FFFFFF'
+        text_color = '#000000'
+
     # Create figure instance
     height = (0.4*len(cmaps_list)+0.1)*hscale
     fig, axs = plt.subplots(figsize=(6.4*wscale, height),
@@ -506,9 +621,6 @@ def create_cmap_overview(cmaps=None, *, savefig=None, use_types=True,
 
         # If cmap is a tuple, it defines a title or cm_type
         if isinstance(cmap, tuple):
-            # Calculate title_pos
-            title_pos = left_pos+(1-spacing-left_pos)/2
-
             # If it is a title
             if cmap[1]:
                 # Write the title as text in the correct position
@@ -532,72 +644,87 @@ def create_cmap_overview(cmaps=None, *, savefig=None, use_types=True,
             # Get RGB values for colormap
             rgb = cmap(x)[:, :3]
 
-            # Get lightness values of colormap
-            lab = cspace_convert(rgb)
-            L = lab[:, 0]
-
-            # Normalize lightness values
-            L /= 99.99871678
-
-            # Get corresponding RGB values for lightness values using neutral
-            rgb_L = cmrcm.neutral(L)[:, :3]
-
             # Add colormap subplot
             ax0.imshow(rgb[np.newaxis, ...], aspect='auto')
 
-            # Check if the lightness profile was requested
-            if plot_profile and (cm_type != 'qualitative'):
-                # Determine the points that need to be plotted
-                plot_L = -(L-0.5)
-                points = np.stack([x, plot_L], axis=1)
-
-                # Determine the colors that each point must have
-                # Use black for L >= 0.5 and white for L <= 0.5.
-                colors = np.zeros_like(plot_L, dtype=int)
-                colors[plot_L >= 0] = 1
-
-                # Split points up into segments with the same color
-                s_idx = np.nonzero(np.diff(colors))[0]+1
-                segments = np.split(points, s_idx)
-
-                # Loop over all pairs of adjacent segments
-                for i, (seg1, seg2) in enumerate(zip(segments[:-1],
-                                                     segments[1:])):
-                    # Determine the point in the center of these segments
-                    central_point = (seg1[-1]+seg2[0])/2
-
-                    # Add this point to the ends of these segments
-                    # This ensures that the color changes in between segments
-                    segments[i] = np.concatenate(
-                        [segments[i], [central_point]], axis=0)
-                    segments[i+1] = np.concatenate(
-                        [[central_point], segments[i+1]], axis=0)
-
-                # Create an MPL LineCollection object with these segments
-                lc = LineCollection(segments, cmap=cmrcm.neutral,
-                                    alpha=plot_profile)
-                lc.set_linewidth(1)
-
-                # Determine the colors of each segment
-                s_colors = [colors[0]]
-                s_colors.extend(colors[s_idx])
-                s_colors = np.array(s_colors)
-
-                # Set the values of the line-collection to be these colors
-                lc.set_array(s_colors)
-
-                # Add line-collection to this subplot
-                ax1.add_collection(lc)
-
             # Add gray-scale colormap subplot if requested
             if show_grayscale:
+                # Get lightness values of colormap
+                lab = cspace_convert(rgb)
+                L = lab[:, 0]
+
+                # Normalize lightness values
+                L /= 99.99871678
+
+                # Get RGB values for lightness values using neutral
+                rgb_L = cmrcm.neutral(L)[:, :3]
+
+                # Add grey-scale colormap subplot
                 ax1.imshow(rgb_L[np.newaxis, ...], aspect='auto')
 
-            # Plot the name of the colormap as text
+                # Check if the lightness profile was requested
+                if plot_profile and (cm_type != 'qualitative'):
+                    # Determine the points that need to be plotted
+                    plot_L = -(L-0.5)
+                    points = np.stack([x, plot_L], axis=1)
+
+                    # Determine the colors that each point must have
+                    # Use black for L >= 0.5 and white for L <= 0.5.
+                    colors = np.zeros_like(plot_L, dtype=int)
+                    colors[plot_L >= 0] = 1
+
+                    # Split points up into segments with the same color
+                    s_idx = np.nonzero(np.diff(colors))[0]+1
+                    segments = np.split(points, s_idx)
+
+                    # Loop over all pairs of adjacent segments
+                    for i, (seg1, seg2) in enumerate(zip(segments[:-1],
+                                                         segments[1:])):
+                        # Determine the point in the center of these segments
+                        central_point = (seg1[-1]+seg2[0])/2
+
+                        # Add this point to the ends of these segments
+                        # This ensures that color changes in between segments
+                        segments[i] = np.r_[segments[i], [central_point]]
+                        segments[i+1] = np.r_[[central_point], segments[i+1]]
+
+                    # Create an MPL LineCollection object with these segments
+                    lc = LineCollection(segments, cmap=cmrcm.neutral,
+                                        alpha=plot_profile)
+                    lc.set_linewidth(1)
+
+                    # Determine the colors of each segment
+                    s_colors = [colors[0]]
+                    s_colors.extend(colors[s_idx])
+                    s_colors = np.array(s_colors)
+
+                    # Set the values of the line-collection to be these colors
+                    lc.set_array(s_colors)
+
+                    # Add line-collection to this subplot
+                    ax1.add_collection(lc)
+
+            # Determine positions of colormap name
             x_text = pos0.x0-spacing
             y_text = pos0.y0+pos0.height/2
-            fig.text(x_text, y_text, cmap.name,
-                     va='center', ha='right', fontsize=10, c=text_color)
+
+            # Check if lightness information was requested for valid cm_type
+            if show_info and cm_type in ('sequential', 'diverging', 'cyclic'):
+                # If so, obtain lightness/perceptual profile information
+                rank = _get_cmap_perceptual_rank(cmap)[0:6]
+
+                # Write name of colormap in the correct position
+                fig.text(x_text, y_text, cmap.name,
+                         va='bottom', ha='right', fontsize=10, c=text_color)
+
+                # Write lightness profile information in the correct position
+                fig.text(x_text, y_text, "(%.3g, %.3g, %.3g)" %
+                         (rank[2], rank[2]-rank[0]*rank[3], rank[5]),
+                         va='top', ha='right', fontsize=10, c=text_color)
+            else:
+                # If not, just write the name of the colormap
+                fig.text(x_text, y_text, cmap.name,
+                         va='center', ha='right', fontsize=10, c=text_color)
 
     # If savefig is not None, save the figure
     if savefig is not None:
@@ -650,6 +777,45 @@ def get_bibtex():
     print(bibtex.strip())
 
 
+# This function returns a list of all colormaps available in CMasher
+def get_cmap_list(cmap_type='all'):
+    """
+    Returns a list with the names of all colormaps available in *CMasher* of
+    the given `cmap_type`.
+
+    Note that *CMasher* colormaps registered in *MPL* have an added 'cmr.'
+    prefix.
+
+    Optional
+    --------
+    cmap_type : {'a'/'all'; 's'/'seq'/'sequential'; 'd'/'div'/'diverging'; \
+        'c'/'cyc'/'cyclic'}. Default: 'all'
+        The colormap type that should be in the returned list.
+
+    Returns
+    -------
+    cmap_list : list of str
+        List containing the names of all colormaps available in *CMasher*.
+
+    """
+
+    # Convert cmap_type to lowercase
+    cmap_type = cmap_type.lower()
+
+    # Obtain proper list
+    if cmap_type in ('a', 'all'):
+        cmaps = [cmap for cmap in cmrcm.cmap_d]
+    elif cmap_type in ('s', 'seq', 'sequential'):
+        cmaps = [cmap for cmap in cmrcm.cmap_cd['sequential']]
+    elif cmap_type in ('d', 'div', 'diverging'):
+        cmaps = [cmap for cmap in cmrcm.cmap_cd['diverging']]
+    elif cmap_type in ('c', 'cyc', 'cyclic'):
+        cmaps = [cmap for cmap in cmrcm.cmap_cd['cyclic']]
+
+    # Return cmaps
+    return(cmaps)
+
+
 # This function determines the colormap type of a given colormap
 def get_cmap_type(cmap):
     """
@@ -779,8 +945,8 @@ def get_sub_cmap(cmap, start, stop, *, N=None):
     and `stop` that are too close to each other, may result in a colormap that
     contains too few different colors to be smooth.
     It is recommended to use at least 128 different colors in a colormap for
-    optimal results (*CMasher* colormaps have 256 or 511 different colors, for
-    sequential or diverging colormaps respectively).
+    optimal results (*CMasher* colormaps have 256 or 511/510 different colors,
+    for sequential or diverging/cyclic colormaps respectively).
     One can check the number of colors in a colormap with
     :attr:`matplotlib.colors.Colormap.N`.
 
@@ -927,7 +1093,7 @@ def import_cmaps(cmap_path):
                 idx = len(rgb)//2
 
                 # Shift the entire colormap by this index
-                rgb_s = np.concatenate([rgb[idx:], rgb[:idx]], axis=0)
+                rgb_s = np.r_[rgb[idx:], rgb[:idx]]
 
                 # Register this colormap as well
                 register_cmap(cm_name+'_s', rgb_s)
@@ -1164,6 +1330,65 @@ def take_cmap_colors(cmap, N, *, cmap_range=(0, 1), return_fmt='float'):
     return(colors)
 
 
+# Function to view what a colormap looks like
+def view_cmap(cmap, *, savefig=None):
+    """
+    Shows a simple plot of the provided `cmap`.
+
+    Parameters
+    ----------
+    cmap : str or :obj:`~matplotlib.colors.Colormap` object
+        The registered name of the colormap in :mod:`matplotlib.cm` or its
+        corresponding :obj:`~matplotlib.colors.Colormap` object.
+
+    Optional
+    --------
+    savefig : str or None. Default: None
+        If not *None*, the path where the plot must be saved to.
+        Else, the plot will simply be shown.
+
+    """
+
+    # Obtain RGB values of cmap in provided range
+    rgb = np.array(take_cmap_colors(cmap, None))
+
+    # Create figure
+    fig, ax = plt.subplots(figsize=(12.8, 3.2))
+
+    # Create plot
+    ax.imshow(rgb[np.newaxis, ...], aspect='auto')
+
+    # Turn axes off
+    ax.set_axis_off()
+    plt.tight_layout(0, 0, 0)
+
+    # If savefig is not None, save the figure
+    if savefig is not None:
+        plt.savefig(savefig, dpi=100, bbox_inches='tight', pad_inches=0)
+        plt.close(fig)
+
+    # Else, simply show it
+    else:
+        plt.show()
+
+
 # %% IMPORT SCRIPT
 # Import all colormaps defined in './colormaps'
 import_cmaps(path.join(path.dirname(__file__), 'colormaps'))
+
+
+# Raise warning about 'heat' being renamed to 'torch' in v1.6.1
+class LC_heat(LC):  # pragma: no cover
+    def __call__(self, *args, **kwargs):
+        warnings.warn("The 'heat' colormap was renamed to 'torch' in v1.6.1 "
+                      "and will be removed in v1.7.", FutureWarning,
+                      stacklevel=2)
+        return(super().__call__(*args, **kwargs))
+
+
+_LC = LC
+LC = LC_heat
+with warnings.catch_warnings():
+    warnings.simplefilter('ignore')
+    register_cmap('heat', cmrcm.torch.colors)
+LC = _LC
